==> client-lib-1.3.1-sources.jar: io/baltoro/domain/BaltoroAppAPI.java <==
package io.baltoro.domain;

import java.sql.Timestamp;

public class BaltoroAppAPI
{
	private String uuid;
	private String appUuid;
	private String state;
	private String path;
	private String roles;
	private String createdBy;
	private Timestamp createdOn;
	private boolean authRequired;
	private boolean discoverable;
	private String propsJson;

	
	
	public String getUuid()
	{
		return uuid;
	}
	public void setUuid(String uuid)
	{
		this.uuid = uuid;
	}
	
	
	
	
	public String getCreatedBy()
	{
		return createdBy;
	}
	public void setCreatedBy(String createdBy)
	{
		this.createdBy = createdBy;
	}
	
	public Timestamp getCreatedOn()
	{
		return createdOn;
	}
	public void setCreatedOn(Timestamp createdOn)
	{
		this.createdOn = createdOn;
	}
	
	public String getPath()
	{
		return path;
	}
	public void setPath(String path)
	{
		this.path = path;
	}
	public String getRoles()
	{
		return roles;
	}
	public void setRoles(String roles)
	{
		this.roles = roles;
	}
	public String getAppUuid()
	{
		return appUuid;
	}
	public void setAppUuid(String appUuid)
	{
		this.appUuid = appUuid;
	}
	public boolean isAuthRequired()
	{
		return authRequired;
	}
	public void setAuthRequired(boolean authRequired)
	{
		this.authRequired = authRequired;
	}
	public String getState()
	{
		return state;
	}
	public void setState(String state)
	{
		this.state = state;
	}
	public boolean isDiscoverable()
	{
		return discoverable;
	}
	public void setDiscoverable(boolean discoverable)
	{
		this.discoverable = discoverable;
	}
	public String getPropsJson()
	{
		return propsJson;
	}
	public void setPropsJson(String propsJson)
	{
		this.propsJson = propsJson;
	}
	
	
	
	
}

==> client-lib-2.1.1-sources.jar: io/baltoro/domain/BaltoroAppAPI.java <==
package io.baltoro.domain;

import java.sql.Timestamp;

public class BaltoroAppAPI
{
	private String uuid;
	private String appUuid;
	private String state;
	private String path;
	private String roles;
	private String createdBy;
	private Timestamp createdOn;
	private boolean authRequired;
	private boolean discoverable;
	private String propsJson;
	private int timeoutSec = 20;

	
	
	public String getUuid()
	{
		return uuid;
	}
	public void setUuid(String uuid)
	{
		this.uuid = uuid;
	}
	
	
	
	
	public String getCreatedBy()
	{
		return createdBy;
	}
	public void setCreatedBy(String createdBy)
	{
		this.createdBy = createdBy;
	}
	
	public Timestamp getCreatedOn()
	{
		return createdOn;
	}
	public void setCreatedOn(Timestamp createdOn)
	{
		this.createdOn = createdOn;
	}
	
	public String getPath()
	{
		return path;
	}
	public void setPath(String path)
	{
		this.path = path;
	}
	public String getRoles()
	{
		return roles;
	}
	public void setRoles(String roles)
	{
		this.roles = roles;
	}
	public String getAppUuid()
	{
		return appUuid;
	}
	public void setAppUuid(String appUuid)
	{
		this.appUuid = appUuid;
	}
	public boolean isAuthRequired()
	{
		return authRequired;
	}
	public void setAuthRequired(boolean authRequired)
	{
		this.authRequired = authRequired;
	}
	public String getState()
	{
		return state;
	}
	public void setState(String state)
	{
		this.state = state;
	}
	public boolean isDiscoverable()
	{
		return discoverable;
	}
	public void setDiscoverable(boolean discoverable)
	{
		this.discoverable = discoverable;
	}
	public String getPropsJson()
	{
		return propsJson;
	}
	public void setPropsJson(String propsJson)
	{
		this.propsJson = propsJson;
	}
	public int getTimeoutSec()
	{
		return timeoutSec;
	}
	public void setTimeoutSec(int timeoutSec)
	{
		this.timeoutSec = timeoutSec;
	}
	
	
}
